// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
import { __assign } from "tslib";
import { getTracer } from "@azure/core-tracing";
import { SpanKind } from "@opentelemetry/api";
/**
 * Creates a span using the global tracer.
 * @internal
 * @param name The name of the operation being performed.
 * @param tracingOptions The options for the underlying http request.
 */
export function createSpan(operationName, operationOptions) {
    var tracer = getTracer();
    var tracingOptions = operationOptions.tracingOptions || {};
    var spanOptions = __assign(__assign({}, tracingOptions.spanOptions), { kind: SpanKind.INTERNAL });
    var span = tracer.startSpan("DigitalTwinsClient." + operationName, spanOptions);
    span.setAttribute("az.namespace", "Microsoft.DigitalTwins");
    var newSpanOptions = tracingOptions.spanOptions || {};
    if (span.isRecording()) {
        newSpanOptions = __assign(__assign({}, tracingOptions.spanOptions), { parent: span.context(), attributes: __assign(__assign({}, spanOptions.attributes), { "az.namespace": "Microsoft.DigitalTwins" }) });
    }
    var newTracingOptions = __assign(__assign({}, tracingOptions), { spanOptions: newSpanOptions });
    var newOperationOptions = __assign(__assign({}, operationOptions), { tracingOptions: newTracingOptions });
    return {
        span: span,
        updatedOptions: newOperationOptions
    };
}
//# sourceMappingURL=tracing.js.map